<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Autohide idle time</source>
        <translation>Inaktivitätsdauer</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n Sekunde</numerusform><numerusform>%n Sekunden</numerusform></translation>
    </message>
    <message>
        <source>Buddies list</source>
        <translation>Kontaktliste</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Buddies window</source>
        <translation>Kontaktfenster</translation>
    </message>
    <message>
        <source>Hide buddy list window when unused</source>
        <translation>Kontaktlistenfenster ausblenden, wenn es nicht benutzt wird</translation>
    </message>
</context>
<context>
    <name>AutoHideConfigurationUiHandler</name>
    <message>
        <source>Don&apos;t hide</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>